@@ -7,12 +7,15 @@ Author: Abraham Lee
 Copyright: 2013
 
 """
-__author__ = 'Abraham Lee'
-__version__ = '0.3.3'
+# from __future__ import absolute_import
 
-from doe_box_behnken import *
-from doe_composite import *
-from doe_factorial import *
-from doe_lhs import *
-from doe_fold import *
-from doe_plackett_burman import *
+__author__ = 'Abraham Lee'
+__version__ = '0.3.4'
+
+from pyDOE.doe_box_behnken import *
+from pyDOE.doe_composite import *
+from pyDOE.doe_factorial import *
+from pyDOE.doe_lhs import *
+from pyDOE.doe_fold import *
+from pyDOE.doe_plackett_burman import *
+    
