@@ -36,11 +36,11 @@ def fold(H, columns=None):
         vals = np.unique(H[:, col])
         assert len(vals)==2, 'Input design matrix must be 2-level factors only.'
         
-        for i in xrange(H.shape[0]):
+        for i in range(H.shape[0]):
             Hf[i, col] = vals[0] if H[i, col]==vals[1] else vals[1]
     
     Hf = np.vstack((H, Hf))
     
     return Hf
         
-    
\ No newline at end of file
+    
